@@ -105,7 +105,6 @@
 
 #include "clutter-gst-private.h"
 #include "clutter-gst-debug.h"
-#include "clutter-gst-video-sink.h"
 #include "clutter-gst-util.h"
 
 static gboolean clutter_gst_is_initialized = FALSE;
@@ -144,15 +143,15 @@ clutter_gst_init (int    *argc,
 #ifdef CLUTTER_GST_ENABLE_DEBUG
   _clutter_gst_debug_init();
 #endif
-  gst_plugin_register_static (GST_VERSION_MAJOR,
-			      GST_VERSION_MINOR,
-			      "cluttersink",
-			      "Element to render to Clutter textures",
-			      _internal_plugin_init,
-			      VERSION,
-			      "LGPL", /* license */
-			      "clutter-gst", PACKAGE,
-			      "http://www.clutter-project.org");
+  /* gst_plugin_register_static (GST_VERSION_MAJOR, */
+  /*       		      GST_VERSION_MINOR, */
+  /*       		      "cluttersink", */
+  /*       		      "Element to render to ClutterGst actors", */
+  /*       		      /\* _internal_plugin_init *\/NULL, */
+  /*       		      VERSION, */
+  /*       		      "LGPL", /\* license *\/ */
+  /*       		      "clutter-gst", PACKAGE, */
+  /*       		      "http://www.clutter-project.org"); */
 
 
   clutter_gst_is_initialized = TRUE;
@@ -224,15 +223,15 @@ clutter_gst_init_with_args (int            *argc,
 #ifdef CLUTTER_GST_ENABLE_DEBUG
   _clutter_gst_debug_init ();
 #endif
-  gst_plugin_register_static (GST_VERSION_MAJOR,
-			      GST_VERSION_MINOR,
-			      "cluttersink",
-			      "Element to render to Clutter textures",
-			      _internal_plugin_init,
-			      VERSION,
-			      "LGPL", /* license */
-			      "clutter-gst", PACKAGE,
-			      "http://www.clutter-project.org");
+  /* gst_plugin_register_static (GST_VERSION_MAJOR, */
+  /*       		      GST_VERSION_MINOR, */
+  /*       		      "cluttersink", */
+  /*       		      "Element to render to ClutterGst actors", */
+  /*       		      /\* _internal_plugin_init *\/NULL, */
+  /*       		      VERSION, */
+  /*       		      "LGPL", /\* license *\/ */
+  /*       		      "clutter-gst", PACKAGE, */
+  /*       		      "http://www.clutter-project.org"); */
 
 
   clutter_gst_is_initialized = TRUE;
@@ -241,26 +240,50 @@ clutter_gst_init_with_args (int            *argc,
 }
 
 /**
- * clutter_gst_video_sink_new:
- * @texture: a #ClutterTexture
+ * clutter_gst_create_video_sink:
  *
- * Creates a new GStreamer video sink which uses @texture as the target
- * for sinking a video stream from GStreamer.
+ * Creates a new #CoglGstVideoSink initialized with Clutter's Cogl context.
  *
- * <note>This function has to be called from Clutter's main thread. While
- * GStreamer will spawn threads to do its work, we want all the GL calls to
- * happen in the same thread. Clutter-gst knows which thread it is by
- * assuming this constructor is called from the Clutter thread.</note>
+ * Return value: (transfer full): the newly created #CoglGstVideoSink.
  *
- * Return value: a #GstElement for the newly created video sink
- *
- * Deprecated: 1.6: Use gst_element_factory_make ("cluttersink", ...) and the
- * "texture" GObject property instead.
+ * Since: 3.0
  */
 GstElement *
-clutter_gst_video_sink_new (ClutterTexture *texture)
+clutter_gst_create_video_sink (void)
 {
-  return g_object_new (CLUTTER_GST_TYPE_VIDEO_SINK,
-                       "texture", texture,
-                       NULL);
+  return GST_ELEMENT (cogl_gst_video_sink_new (clutter_gst_get_cogl_context ()));
+}
+
+/**/
+
+CoglContext *
+clutter_gst_get_cogl_context (void)
+{
+  return clutter_backend_get_cogl_context (clutter_get_default_backend ());
+}
+
+ClutterGstFrame *
+clutter_gst_create_blank_frame (const ClutterColor *color)
+{
+  CoglTexture *texture;
+  CoglPipeline *pipeline;
+  ClutterGstFrame *frame;
+  ClutterColor black_color = { 0x0, 0x0, 0x0, 0xff };
+  const guint8 *color_ptr = color != NULL ?
+    (const guint8 *) color : (const guint8 *) &black_color;
+
+  texture = cogl_texture_new_from_data (1, 1, COGL_TEXTURE_NONE,
+                                        COGL_PIXEL_FORMAT_RGBA_8888,
+                                        COGL_PIXEL_FORMAT_RGBA_8888,
+                                        1,
+                                        color_ptr);
+  pipeline = cogl_pipeline_new (clutter_gst_get_cogl_context ());
+  cogl_pipeline_set_layer_texture (pipeline, 0, texture);
+
+  frame = clutter_gst_frame_new (pipeline);
+
+  cogl_object_unref (pipeline);
+  cogl_object_unref (texture);
+
+  return frame;
 }
