@@ -32,10 +32,15 @@
 
 #include "clutter-gst-types.h"
 #include "clutter-gst-enum-types.h"
-#include "clutter-gst-video-sink.h"
-#include "clutter-gst-video-texture.h"
+#include "clutter-gst-aspectratio.h"
+#include "clutter-gst-camera-device.h"
+#include "clutter-gst-camera-manager.h"
+#include "clutter-gst-camera.h"
+#include "clutter-gst-content.h"
+#include "clutter-gst-crop.h"
+#include "clutter-gst-playback.h"
+#include "clutter-gst-player.h"
 #include "clutter-gst-util.h"
 #include "clutter-gst-version.h"
-#include "clutter-gst-player.h"
 
 #endif /* __CLUTTER_GST_H__ */
