@@ -32,6 +32,7 @@
 
 #include <glib/gprintf.h>
 #include <clutter-gst/clutter-gst.h>
+#include <cogl-gst/cogl-gst.h>
 
 static gint   opt_framerate = 30;
 static gchar *opt_fourcc    = "I420";
@@ -65,43 +66,6 @@ parse_fourcc (const gchar *fourcc)
   return GST_STR_FOURCC (fourcc);
 }
 
-void
-size_change (ClutterTexture *texture,
-             gint            width,
-             gint            height,
-             gpointer        user_data)
-{
-  ClutterActor *stage;
-  gfloat new_x, new_y, new_width, new_height;
-  gfloat stage_width, stage_height;
-
-  stage = clutter_actor_get_stage (CLUTTER_ACTOR (texture));
-  if (stage == NULL)
-    return;
-
-  clutter_actor_get_size (stage, &stage_width, &stage_height);
-
-  new_height = (height * stage_width) / width;
-  if (new_height <= stage_height)
-    {
-      new_width = stage_width;
-
-      new_x = 0;
-      new_y = (stage_height - new_height) / 2;
-    }
-  else
-    {
-      new_width  = (width * stage_height) / height;
-      new_height = stage_height;
-
-      new_x = (stage_width - new_width) / 2;
-      new_y = 0;
-    }
-
-  clutter_actor_set_position (CLUTTER_ACTOR (texture), new_x, new_y);
-  clutter_actor_set_size (CLUTTER_ACTOR (texture), new_width, new_height);
-}
-
 int
 main (int argc, char *argv[])
 {
@@ -112,7 +76,7 @@ main (int argc, char *argv[])
   const ClutterColor     rectangle_color = { 96,   0,   0, 255};
   const ClutterRect      rectangle_geom  = { {110,  70}, {100, 100}};
   ClutterActor          *stage;
-  ClutterActor          *texture;
+  ClutterActor          *actor;
   ClutterActor          *rectangle;
   ClutterTransition     *animation;
 
@@ -122,12 +86,9 @@ main (int argc, char *argv[])
   GstElement            *sink;
   GstCaps               *caps;
 
-  if (!g_thread_supported ())
-    g_thread_init (NULL);
-
   result = clutter_gst_init_with_args (&argc,
                                        &argv,
-                                       " - Test alpha with video textures",
+                                       " - Test alpha with video actors",
                                        options,
                                        NULL,
                                        &error);
@@ -153,26 +114,23 @@ main (int argc, char *argv[])
                           rectangle_geom.size.width,
                           rectangle_geom.size.height);
 
-  /* We need to set certain props on the target texture currently for
-   * efficient/corrent playback onto the texture (which sucks a bit)
-   */
-  texture = g_object_new (CLUTTER_TYPE_TEXTURE,
-                          "disable-slicing", TRUE,
-                          NULL);
-  clutter_actor_set_opacity (texture, 0);
-
-  g_signal_connect (CLUTTER_TEXTURE (texture),
-                    "size-change",
-                    G_CALLBACK (size_change), NULL);
-
   /* Set up pipeline */
   pipeline = GST_PIPELINE(gst_pipeline_new (NULL));
 
   src = gst_element_factory_make ("videotestsrc", NULL);
   g_object_set (G_OBJECT (src), "pattern", 1, NULL);
   capsfilter = gst_element_factory_make ("capsfilter", NULL);
-  sink = gst_element_factory_make ("cluttersink", NULL);
-  g_object_set (G_OBJECT (sink), "texture", CLUTTER_TEXTURE (texture), NULL);
+  sink = clutter_gst_create_video_sink ();
+
+  /* Video actor */
+  actor = g_object_new (CLUTTER_TYPE_ACTOR,
+                        "content", g_object_new (CLUTTER_GST_TYPE_CONTENT,
+                                                 "video-sink", sink,
+                                                 NULL),
+                        "width", clutter_actor_get_width (stage),
+                        "height", clutter_actor_get_height (stage),
+                        NULL);
+  clutter_actor_set_opacity (actor, 0);
 
   /* make videotestsrc spit the format we want */
   if (g_strcmp0 (opt_fourcc, "RGB ") == 0)
@@ -204,18 +162,18 @@ main (int argc, char *argv[])
   gst_element_set_state (GST_ELEMENT(pipeline), GST_STATE_PLAYING);
 
   clutter_actor_add_child (stage, rectangle);
-  clutter_actor_add_child (stage, texture);
+  clutter_actor_add_child (stage, actor);
   clutter_actor_show (stage);
 
-  clutter_actor_save_easing_state (texture);
-  clutter_actor_set_easing_mode (texture, CLUTTER_LINEAR);
-  clutter_actor_set_easing_duration (texture, 6000);
+  clutter_actor_save_easing_state (actor);
+  clutter_actor_set_easing_mode (actor, CLUTTER_LINEAR);
+  clutter_actor_set_easing_duration (actor, 6000);
 
-  clutter_actor_set_opacity (texture, 0xff);
+  clutter_actor_set_opacity (actor, 0xff);
 
-  clutter_actor_restore_easing_state (texture);
+  clutter_actor_restore_easing_state (actor);
 
-  animation = clutter_actor_get_transition (texture, "opacity");
+  animation = clutter_actor_get_transition (actor, "opacity");
   clutter_timeline_set_repeat_count (CLUTTER_TIMELINE (animation), -1);
 
   clutter_main();
